A one-mode network of 28 individuals represented as a `network` object.

cocaine_dealing_net

Format

An `network` object with 28 nodes and 40 edges.

Details

The network comes from an investigation into to a large cocaine trafficking organization in New York City. The ties are communications through police wiretaps and represented as directed binary relations.

Vertex attributes: - `vertex.names`: Name of individual

References

Natarajan, M. (2000). *Understanding the Structure of a Drug Trafficking Organization: A Conversational Analysis*. In M. Natarajan & M. Hough (Eds.), *Illegal Drug Markets: From Research to Prevention Policy* (Crime Prevention Studies, Vol. 11, pp. 273–298). Criminal Justice Press.

Examples

sna::gplot( cocaine_dealing_net )
#> Error in sna::gplot(cocaine_dealing_net): Error in gplot: no layout function for mode fruchtermanreingold