A one-mode directed network of 38 individuals represented as a `network` object.

heroin_dealing_net

Format

An `network` object with 38 nodes and 1168 edges.

Details

The network comes from an investigation into to a large heroin trafficking organization in New York City. The ties are communications through police wiretaps and represented as directed binary relations.

Vertex attributes: - `vertex.names`: Name of individual

References

Natarajan, M. (2006). Understanding the structure of a large heroin distribution network: A quantitative analysis of qualitative data. *Journal of Quantitative Criminology*, 22(2), 171–192. https://doi.org/10.1007/s10940-006-9007-x

Examples

sna::gplot( heroin_dealing_net )
#> Error in sna::gplot(heroin_dealing_net): Error in gplot: no layout function for mode fruchtermanreingold